# Functional aspects of interneuron morphology in the subiculum

Interneurons in the subiculum have a polarized axonal cloud instead of a circular as found in other brain regions. Additionally, pyramidal neurons in the subiculum lack recurrent connections, but they connect via recurrent inhibition. Therefore, inhibition plays a major role in this circuitry and we pose the question, which function the extraordinary axon morphology serves in this setting.



### How to setup the python environment

It is recommended to use Anaconda (https://www.continuum.io/downloads) to create a virtual environment with the necessary dependencies. With anaconda, it is a one button install. After cloning the repository and changing into the root folder, type
```
conda env create -f environment.yml
```

This creates an environment called interneuron_polarity, which can be activated via
```bash
conda activate interneuron_polarity
```

To run the scripts, you also need to make the repository folder available in the python path (requires conda--build)
```bash
conda develop .
```

If you need additional packages, install them via `conda install` and update the environment file via

```bash
conda env export > environment.yml
```

To update the existing environment
```bash
conda-env update -f environment.yml
```

### How to run the simulation

The entire process is split in three main scripts. The simulation is setup and run in
```bash
run_simulation_perlin_map.py
```
Relevant parameters are the range of scale and seed values for the input map generation as explained in the script. 
A preliminary analysis of the simulated data is done by running 
```bash
preliminary_analysis_perlin_map.py
```
The final analysis and figure generation is done by 
```bash
final_analysis_and_plotting_perlin_map.py
```
Note, that running the simulation script will overwrite the saved data. 
The bulk of the runtime lies within the simulation and preliminary analysis which can be executed together via
```bash
run_and_analyze_perlin.py
```
after which the figure script can be tweaked and executed without loss of data.

For the supplement figure, a pinwheel map is used as an alternative input map. The run, analyse and plot scripts are organized in the same manner but found in the folder pinwheel_map. 

### Additional Ressources

The simulation saves the generated data in a hdf5-file. Since the full parameter exploration used for the model section of the paper requires significant time to run, the generated data set can also be downloaded from the following location. When the pre-simulated dataset is used, only the figure script needs to be executed to get the results of the data analysis. Note that the save file will be overwritten when the simulation is started again.

- Full perlin data set
- Full pinwheel data set
- Pregenerated pinwheel maps
